dnl Get a key from ruby's configuration table

AC_DEFUN([RP_LANG_RUBY], [

AC_ARG_WITH(
    [ruby],
    AC_HELP_STRING(
     --with-ruby=PATH,
     [ path to the ruby interpreter [[ruby]] ]),
    [WITH_RUBY=$withval],
    [WITH_RUBY=ruby])

AC_ARG_WITH(
    ruby_sitelibdir,
    AC_HELP_STRING(
     --with-ruby-sitelibdir=PATH,
     [ path to install ruby scripts [[auto-detect]] ]),
    [WITH_RUBY_SITELIBDIR=$withval],
    [WITH_RUBY_SITELIBDIR=""])

echo RUBY=$WITH_RUBY
if test "$WITH_RUBY" != "no" ; then
  if test "$WITH_RUBY" = "yes" ; then
    AC_PATH_PROG(RUBY, [ruby], [no])
  fi
else
  RUBY=$WITH_RUBY
fi
echo "after RUBY=$RUBY"
if test "$RUBY" = "no" ; then
  RUBY="/bin/true"
fi
AC_SUBST(WITH_RUBY)
AC_SUBST(RUBY)

. ${srcdir}/cf/rp_ruby_functions.sh

#AC_DEFUN([RUBY_CONFIG], [
# $RUBY -rrbconfig -e "puts(RbConfig::CONFIG[['$1']])"])

RUBY_VERSION_CODE=`$RUBY -e "puts RUBY_VERSION.gsub(/\./, '')"`
AC_SUBST(RUBY_VERSION_CODE)

RUBY_VERSION=`ruby_get_config_param "ruby_version"`
RUBY_CONFIG_ARCHDIR=`ruby_get_config_param "archdir"`
RUBY_CONFIG_ARCH=`ruby_get_config_param "arch"`
RUBY_CONFIG_LIBDIR=`ruby_get_config_param "libdir"`
RUBY_CONFIG_BINDIR=`ruby_get_config_param "bindir"`
RUBY_CONFIG_RUBYHDRDIR=`ruby_get_config_param rubyhdrdir`
RUBY_CONFIG_CFLAGS=`ruby_get_config_param CFLAGS`
RUBY_CONFIG_LIBS=`ruby_get_config_param LIBS`
RUBY_CONFIG_DLDLIBS=`ruby_get_config_param DLDLIBS`
RUBY_CONFIG_LDFLAGS=`ruby_get_config_param LDFLAGS`
RUBY_CONFIG_SITELIBDIR=`ruby_get_config_param sitelibdir`
RUBY_CONFIG_LIBRUBYARG=`ruby_get_config_param LIBRUBYARG`
RUBY_CONFIG_LIBRUBYARG_STATIC=`ruby_get_config_param "LIBRUBYARG_STATIC"`
RUBY_CONFIG_CCDLFLAGS=`ruby_get_config_param "CCDLFLAGS"`
echo RUBY_CONFIG_ARCHDIR=$RUBY_CONFIG_ARCHDIR
echo RUBY_CONFIG_ARCH=$RUBY_CONFIG_ARCH
echo RUBY_CONFIG_LIBDIR=$RUBY_CONFIG_LIBDIR
echo RUBY_CONFIG_BINDIR=$RUBY_CONFIG_BINDIR
echo RUBY_CONFIG_RUBYHDRDIR=$RUBY_CONFIG_RUBYHDRDIR
echo RUBY_CONFIG_CFLAGS=$RUBY_CONFIG_CFLAGS
echo RUBY_CONFIG_LDFLAGS=$RUBY_CONFIG_LDFLAGS
echo RUBY_CONFIG_SITELIBDIR=$RUBY_CONFIG_SITELIBDIR
echo RUBY_VERSION=$RUBY_VERSION

if test "x${RUBY_CONFIG_RUBYHDRDIR}" != "x"; then
  # 1.9
  RUBY_CPPFLAGS="-I${RUBY_CONFIG_RUBYHDRDIR}"
  RUBY_CPPFLAGS="${RUBY_CPPFLAGS} -I${RUBY_CONFIG_RUBYHDRDIR}/${RUBY_CONFIG_ARCH}"
  echo RUBY_CPPFLAGS=$RUBY_CPPFLAGS"
else
  # 1.8
  RUBY_CPPFLAGS="-I${RUBY_CONFIG_ARCHDIR}"
  echo "RUBY_CPPFLAGS=$RUBY_CPPFLAGS"
fi
AC_SUBST(RUBY_CPPFLAGS)

RUBY_CFLAGS="${RUBY_CONFIG_CFLAGS} ${RUBY_CONFIG_CCDLFLAGS}"
AC_SUBST(RUBY_CFLAGS)

RUBY_CXXFLAGS="${RUBY_CONFIG_CFLAGS} ${RUBY_CONFIG_CCDLFLAGS}"
AC_SUBST(RUBY_CXXFLAGS)

RUBY_LDFLAGS="-L${RUBY_CONFIG_ARCHDIR} -L${RUBY_CONFIG_LIBDIR} ${RUBY_CONFIG_LDFLAGS}"
AC_SUBST(RUBY_LDFLAGS)

RUBY_LIBS="${RUBY_CONFIG_LIBS} ${RUBY_CONFIG_DLDLIBS}"
AC_SUBST(RUBY_LIBS)
 
RUBY_LIBRUBYARG="${RUBY_CONFIG_LIBRUBYARG}"
AC_SUBST(RUBY_LIBRUBYARG)

RUBY_LIBRUBYARG_STATIC="${RUBY_CONFIG_LIBRUBYARG_STATIC}"
AC_SUBST(RUBY_LIBRUBYARG_STATIC)

dnl The fourth parameter to AC_CHECK_HEADER keeps autoconf from
dnl searching for standard header files as a side-effect (which we want)
CPPFLAGS_save="${CPPFLAGS}"
CPPFLAGS="${CPPFLAGS} ${RUBY_CPPFLAGS} -I${RUBY_HEADER_DIR}"
echo CPPFLAGS=$CPPFLAGS
AC_CHECK_HEADERS(ruby.h)
HAVE_RUBY_H=${ac_cv_header_ruby_h}
AC_SUBST(HAVE_RUBY_H)

AC_CHECK_HEADERS(node.h,,,[
#include <ruby.h>
])
AC_CHECK_HEADERS(ruby/node.h,
[ AC_DEFINE(REALLY_HAVE_RUBY_NODE_H, [],
[ Define this macro to use ruby/node.h ]) ],
                            ,[
			     #include <ruby.h>
])
AC_CHECK_HEADERS(version.h,,,[
#include <ruby.h>
])
AC_CHECK_HEADERS(env.h,,,[
#include <ruby.h>
])

CPPFLAGS="${CPPFLAGS_save}"

AC_MINGW32

if test "${MINGW32}" = yes; then
  RB_FIX_MINGW_LIBS
fi

]) dnl RB_INIT_RUBY

dnl We would like to be able to build using MingW against the one-click
dnl installer, which is built using VC6.  So, we detect this situation
dnl and fix up the link step if this is the case.
dnl
dnl Static linking isn't likely to work correctly, so we disable it by
dnl default, but if the user asks for LIBRUBYARG_STATIC, they'll still
dnl get static linking.
AC_DEFUN([RB_FIX_MINGW_LIBS], [
RUBY_LIBS=`echo ${RUBY_LIBS} | sed -e "s%oldnames.lib%-lmoldname%"`
RUBY_LIBS=`echo ${RUBY_LIBS} | sed -e "s%user32.lib%-luser32%"`
RUBY_LIBS=`echo ${RUBY_LIBS} | sed -e "s%advapi32.lib%-ladvapi32%"`
RUBY_LIBS=`echo ${RUBY_LIBS} | sed -e "s%ws2_32.lib%-lws2_32%"`
RUBY_LIBRUBYARG=`echo ${RUBY_LIBRUBYARG} | sed -e "s%\(msvcrt-ruby.*\).lib%${RUBY_CONFIG_BINDIR}/\1.dll%"`
RUBY_LIBRUBYARG_STATIC=`echo ${RUBY_LIBRUBYARG_STATIC} | sed -e "s%\(msvcrt-ruby.*\).lib%${RUBY_CONFIG_LIBDIR}/\1.lib%"`
]) dnl RB_FIX_MINGW_LIBS

dnl vim:ft=config
